<?php

/**
 * Class ThreeDSCheckout
 *
 * @package  Conexa\ClipTransparent\Gateway;
 */

namespace Conexa\ClipTransparent\Gateway;

use Conexa\ClipTransparent\Includes\Helper\Helper;

defined('ABSPATH') || exit();
/**
 * Post Checkout Page Controller
 */
class ThreeDSCheckout
{

	/**
	 * Run Action
	 *
	 * @param int $order_id ID for WC Order.
	 *
	 * @return bool
	 */
	public static function render($order_id)
	{

		$error = false;
		$order = wc_get_order($order_id);

		if (!wp_verify_nonce(sanitize_text_field(wp_unslash($_GET['clip_transparent_nonce'])), \ClipTransparent::GATEWAY_ID)) {
			$error = true;
		}

		if (\ClipTransparent::GATEWAY_ID !== $order->get_payment_method()) {
			$error = true;
		}

		if ($error) {
			return false;
		}

		$pending_action_url = $order->get_meta(\ClipTransparent::META_ORDER_3DS_URL);
		$decodedUrl = htmlspecialchars_decode($pending_action_url);
		$threeds = \ClipTransparent::get_url( 'three_ds' );


		if (isset($pending_action_url) && !empty($pending_action_url)) {

			echo '<div style="position: fixed; top: 0; left: 0; width: 100% !important; height: 100% !important; border: none; z-index: 9999; background-color: white;">';
			echo '<iframe id="cybersourceIframe" class="styles.iframe" title="cybersource3Ds" src="' . $decodedUrl . '" data-testid="cybersource3Ds-iframe" allowfullscreen width="100%" height="100%"></iframe>';
			echo '</div>';

			wp_register_script(
				'clip-transparent-checkout',
				Helper::get_assets_folder_url() . '/js/clip-transparent-checkout.js',
				array( 'jquery' ),
				\ClipTransparent::VERSION,
				true
			);
			wp_enqueue_script( 'clip-transparent-checkout' );
			
			wp_localize_script( 'clip-transparent-checkout', 'clip_transparent_object',
				array(
					'nonce' => wp_create_nonce('wc-clip_transparent'),
					'admin_ajax' => esc_url( admin_url('admin-ajax.php') ),
					'threeds' => $threeds,
					'order_id' => $order_id,
					'mode'	=> \ClipTransparent::MODE,
				)
			);


        }else{
			?>
			<p> <?php echo esc_html__('An error occurs while processing your request', 'clip-transparent'); ?></p>
			<a id="select-gateway" class="button btn btn-secondary" href="<?php echo esc_url(wc_get_checkout_url()); ?>">
				<span>
					<?php echo esc_html__('Select another payment method', 'clip-transparent'); ?>
				</span>
			</a>
			<?php
		}
		return true;
	}
}
