<?php

/**
 * Class ThreeDSComplete
 *
 * @package  Conexa\ClipTransparent\Gateway;
 */

namespace Conexa\ClipTransparent\Gateway;

use Conexa\ClipTransparent\Includes\Helper\Helper;
use Conexa\ClipTransparent\Sdk\ClipTransparentSdk;

defined('ABSPATH') || exit();

class ThreeDSComplete {

	public static function get_data() {

        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'wc-clip_transparent')) {
            wp_send_json_error(["error_description" => "Invalid nonce"]);
            return false;
        }

        if (isset($_POST['order_id'])) {
            $order_id = filter_var(wp_unslash($_POST['order_id']), FILTER_SANITIZE_NUMBER_INT);
            $data['order'] = wc_get_order($order_id);
        }

        if (isset($_POST['payment_id'])) {
            // $payment_id = filter_var(wp_unslash($_POST['payment_id']), FILTER_SANITIZE_NUMBER_INT);
            $data['payment_id'] = $_POST['payment_id'];
        }

        if (!empty($data)) {
            return $data;
        }

        return false;
        		
	}

    public static function clip_transparent_3ds_complete()
    {
        $data = self::get_data();
        $order = isset($data['order']) ? $data['order'] : null;
		
        if ($order) {

            $sdk = new clipTransparentSdk(Helper::get_option( 'api_key' ), Helper::get_option( 'api_secret' ));
            $response = $sdk->get_charge_payment( $data['payment_id'] );

            if (isset($response['status']) && 'approved' === $response['status']) {
                
                $order->payment_complete();

                $receipt_no = isset( $response[ 'receipt_no' ] )? $response[ 'receipt_no' ] : '';
                if ( !empty( $receipt_no ) ) {
                    $order->add_order_note(
                        sprintf(
                            /* translators: %s: System Flag */
                            esc_html__( 'Clip Transparent - Approved Payment. Receipt: %s. ID %s', 'clip-transparent' ),
                            $receipt_no,
                            $response['id']
                        )
                    );
                }

                $order->save();

                $order_received_url = wc_get_endpoint_url('order-received', $order->get_id(), wc_get_checkout_url());
                $order_received_url = add_query_arg('key', $order->get_order_key(), $order_received_url);

                //DONE! Redirect to Thank you page
                wp_send_json_success(['redirect' => $order_received_url]);
    
            } else {

                $order->update_meta_data( \ClipTransparent::META_ORDER_3DS_URL,'');
                $order->save();
                $payment_nonce = wp_create_nonce(\ClipTransparent::GATEWAY_ID);
                $order_received_url = add_query_arg('clip_transparent_nonce', $payment_nonce, add_query_arg('clip_transparent_3ds', true, $order->get_checkout_payment_url(true)));
                wp_send_json_success(['redirect' => $order_received_url]);
                
            }
        }
        wp_send_json_error('not order');
    }

}
